@@ -93,6 +93,8 @@ def multiple_replace(string, replacements):
         str: String with replacements
 
     """
+    if not replacements:
+        return string
     pattern = re.compile("|".join([re.escape(k) for k in sorted(replacements, key=len, reverse=True)]), flags=re.DOTALL)
     return pattern.sub(lambda x: replacements[x.group(0)], string)
 
@@ -311,7 +313,7 @@ def get_numeric_if_possible(value):
     def get_int_value(val, denominator):
         val = int(val)
         if denominator != 1:
-            return val / denominator
+            return float(val) / denominator
         else:
             return val
 
